defmodule Mpx.Mixfile do
  use Mix.Project

  def project do
    [
      source_url: "https://github.com/crdschurch/mpx",
      app: :mpx,
      version: "0.2.2",
      elixirc_paths: elixirc_paths(Mix.env),
      start_permanent: Mix.env == :prod,
      deps: deps(),
      package: package(),
      description: description(),
      docs: [
        extras: extras(),
      ],
      name: "MPX"
    ]
  end

  # Run "mix help compile.app" to learn about applications.
  def application do
    [ extra_applications: [:logger, :poison],
      mod: {Mpx, []}]
  end

  defp elixirc_paths(:test), do: ["lib", "test/support"]
  defp elixirc_paths(:integration), do: ["lib", "test/support"]
  defp elixirc_paths(_), do: ["lib"]

  # Run "mix help deps" to learn about dependencies.
  defp deps do
    [
      {:httpoison, "~> 0.12"},
      {:poison, "~> 3.1"},
      {:mock, "~> 0.3.1", only: [:test, :integration]},
      {:credo, "~> 0.8", only: [:dev, :test], runtime: false},
      {:dialyxir, "~> 0.5", only: [:dev], runtime: false},
      {:ex_doc, "~> 0.11", only: :dev},
      {:earmark, "~> 0.1", only: :dev}
    ]
  end

  defp package do
    [
      licenses: ["3-Clause BSD License"],
      files: ["lib", "mix.exs", "README.md", "LICENSE*"],
      maintainers: [ "Matt Silbernagel" ],
      links: %{:GitHub => "https://github.com/crdschurch/mpx"}
    ]
  end

  defp extras do
    [
      "README.md": []
    ]
    |> Enum.map(fn {file, opts} -> {:"#{file}", opts} end)
  end

  defp description do
    "Interact with Ministry Platform's Rest API"
  end
end
